#! /bin/sh
# Test the D-Bus communication between dbus-test-client
# and dbus-test-server
#

rm -f dbus-test-server.log    dbus-test-client.log \
      dbus-test-server.log.ok dbus-test-client.log.ok 2> /dev/null

pid=$(pidof "dbus-daemon")
if [ -z "$pid" ]; then
	echo "dbus-daemon not running. This test needs a running dbus-daemon " \
	     "to communicate with the session-dbus-bus." >&2
	echo "Test ignored." >&2
	exit 77
fi

pid=$(pidof "dbus-test-server")
if [ ! -z "$pid" ]; then
	echo "Another dbus-test-server is already running." >&2
	echo "PID of other process(es): $pid" >&2
	echo >&2
	echo "=- !!! -=" >&2
	echo "You should terminate all other running processes of this kind and " \
	     "then try this test again!" >&2
	echo "=- !!! -=" >&2
	echo >&2
	echo "Aborting test." >&2
	exit 1
fi

# Start the server in background, log output and remember pid
./dbus-test-server > dbus-test-server.log 2>&1 &
pid=$!
echo "./dbus-test-server is running with PID $pid."
echo "Output is written to dbus-test-server.log"
echo

echo "Wait 2 seconds to allow the server to setup..."
sleep 2

# Start the client and log the output
echo "./dbus-test-client is running."
echo "Output is written to dbus-test-client.log"
echo
./dbus-test-client > dbus-test-client.log 2>&1
# Check if the client was successful
return_client=$?
if [ $return_client -ne 0 ]; then
	echo "Client's exist status is $return_client! Test failed." >&2
	exit 1
fi

echo "Kill server softly..."
kill -s QUIT $pid

echo "Wait of server's termination..."
wait $pid
return_server=$?
if [ $return_server -ne 0 ]; then
	echo "Server's exist status is $return_client! Test failed." >&2
	exit 1
fi

echo "Checking logs..."

cat <<EOF > dbus-test-client.log.ok
** Message: All My Profiles
EOF

cat <<EOF > dbus-test-server.log.ok
** Message: D-Bus support has been activated
** Message: Method-Call: dbus_server_next
** Message: Method-Call: dbus_server_previous
** Message: Method-Call: dbus_server_get_profile_status
** Message: Method-Call: dbus_server_set_profile_status -> profile = Set Your Profile!
** Message: Received signal "Quit."
EOF

diff dbus-test-client.log dbus-test-client.log.ok > /dev/null
if [ $? -ne 0 ]; then
	echo "dbus-test-client.log and dbus-test-client.log.ok are NOT equal!" >&2
	echo "Client's NOT log ok. Test failed." >&2
	exit 1
fi
echo "  --> client's log ok"

diff dbus-test-server.log dbus-test-server.log.ok > /dev/null
if [ $? -ne 0 ]; then
	echo "dbus-test-server.log and dbus-test-server.log.ok are NOT equal!" >&2
	echo "Server's NOT log ok. Test failed." >&2
	exit 1
fi
echo "  --> Server's log ok"

echo "Logs ok, check passed!"

rm -f dbus-test-server.log    dbus-test-client.log \
      dbus-test-server.log.ok dbus-test-client.log.ok 2> /dev/null

exit 0
